contexttools.ContextMark
========================

.. abjad-lineage:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark

.. autoclass:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.target_context
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__delattr__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__repr__
   :noindex:
